# Code documentation

WIP

## pyrailroad.elements

### Base elements

::: pyrailroad.elements.Diagram

::: pyrailroad.elements.Start

::: pyrailroad.elements.End

### Text elements

::: pyrailroad.elements.Expression

::: pyrailroad.elements.Terminal

::: pyrailroad.elements.NonTerminal

::: pyrailroad.elements.Comment

::: pyrailroad.elements.Arrow

::: pyrailroad.elements.Skip

### Block elements

::: pyrailroad.elements.Sequence

::: pyrailroad.elements.Stack

::: pyrailroad.elements.OptionalSequence

::: pyrailroad.elements.AlternatingSequence

::: pyrailroad.elements.Choice

::: pyrailroad.elements.MultipleChoice

::: pyrailroad.elements.HorizontalChoice

::: pyrailroad.elements.optional

::: pyrailroad.elements.OneOrMore

::: pyrailroad.elements.zero_or_more

::: pyrailroad.elements.Group

### Misc

::: pyrailroad.elements.DiagramItem

::: pyrailroad.elements.DiagramMultiContainer

::: pyrailroad.elements.Path

::: pyrailroad.elements.Style

::: pyrailroad.elements.TextDiagram
